@@ -201,7 +201,7 @@ class PushHandler:
 			proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
 			interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
 			interface.SystemNoteInfoprint ("fMMS: Failed to download MMS message.")
-			#raise
+			raise
 		
 		return dirname
 
@@ -379,13 +379,7 @@ class MasterConnector:
 	
 	def disconnect(self):
 		try:
-			if (self.config.get_connmode() == CONNMODE_UGLYHACK):
-				self.connector.disconnect()
-			elif (self.config.get_connmode() == CONNMODE_ICDSWITCH):
-				self.connector.disconnect()
-			elif (self.config.get_connmode() == CONNMODE_FORCESWITCH):
-				self.connector.disconnect()
-
+			self.connector.disconnect()
 		except:
 			log.exception("Failed to close connection.")
 	
@@ -401,12 +395,13 @@ class ICDConnector:
 		self.connection = conic.Connection()
 		
 	def connection_cb(self, connection, event, magic):
-		log.info("connection_cb(%s, %s, %x)" % (connection, event, magic))
+		#log.info("connection_cb(%s, %s, %x)" % (connection, event, magic))
 		pass	
 		
 	def disconnect(self):
 		connection = self.connection
                 connection.disconnect_by_id(self.apn)
+                log.info("ICDConnector requested disconnect from id: %s", self.apn)
 	
 	def connect(self):
 		global magic
@@ -420,15 +415,15 @@ class ICDConnector:
 				iap = i
 
 		connection.disconnect()
+		log.info("ICDConnector trying to connect to: %s", iap.get_name())
 		connection.connect("connection-event", self.connection_cb, magic)
 
-		# The request_connection method should be called to initialize
-		# some fields of the instance
-		if not iap:
-			assert(connection.request_connection(conic.CONNECT_FLAG_NONE))
+		if iap:
+			connection.request_connection_by_id(iap.get_id(), conic.CONNECT_FLAG_NONE)
 		else:
-			assert(connection.request_connection_by_id(iap.get_id(), conic.CONNECT_FLAG_NONE))
-			
+			connection.request_connection(conic.CONNECT_FLAG_NONE)
+		
+		
 		
 
 """ this is the 'force switch' autoconnecter """
@@ -447,13 +442,15 @@ class ForceConnector:
 		icd = dbus.Interface(proxy, 'com.nokia.icd')
 		(iapid, arg, arg1, arg2, arg3, arg4, arg5) = icd.get_statistics()
 		self.previousconn = iapid
+		log.info("ForceConnector saved previous connection. ID: %s", iapid)
 		
 	def connection_cb(self, connection, event, magic):
-		log.info("connection_cb(%s, %s, %x)" % (connection, event, magic))
+		#log.info("connection_cb(%s, %s, %x)" % (connection, event, magic))
 		pass
 		
 	""" restore connection to previous """
 	def disconnect(self):
+		log.info("ForceConnector restoring connection...")
 		self.connect(self.previousconn)
 	
 	""" actually disconnects from the current iap before connecting """
@@ -462,6 +459,7 @@ class ForceConnector:
 		
 		args = "DISCONNECT"
 		retcode = subprocess.call(["/opt/fmms/fmms_magic", args])
+		log.info("ForceConnector disconnecting from active connection.")
 
 		if apn == None:
 			apn = self.apn
@@ -473,16 +471,14 @@ class ForceConnector:
 		for i in iaps:
 			if i.get_name() == apn or i.get_id() == apn:
 				iap = i
-
+		
+		log.info("ForceConnector trying to connect to: ID: %s Name: %s" % (iap.get_id(), iap.get_name()))
 		connection.connect("connection-event", self.connection_cb, magic)
-
-		# The request_connection method should be called to initialize
-		# some fields of the instance
-		if not iap:
-			assert(connection.request_connection(conic.CONNECT_FLAG_NONE))
+		
+		if iap:
+			connection.request_connection_by_id(iap.get_id(), conic.CONNECT_FLAG_NONE)
 		else:
-			assert(connection.request_connection_by_id(iap.get_id(), conic.CONNECT_FLAG_NONE))
-
+			connection.request_connection(conic.CONNECT_FLAG_NONE)
 
 
 """ the ugly-hack autoconnector """
@@ -519,7 +515,7 @@ class UglyHackHandler:
 		return conn
 		
 	def disconnect(self):
-		log.info("running disconnect")
+		log.info("UglyHackHandler running disconnect")
 		(apn, ctype, self.iface, self.ipaddr, connected, self.tx, self.rx) = self.conn.GetStatus()
 		args = "STOP %s" % self.iface
 		retcode = subprocess.call(["/opt/fmms/fmms_magic", args])
